@@ -15,6 +15,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import cherrypy
 from ion.db import Db
 
 class Service(object):
@@ -23,9 +24,12 @@ class Service(object):
         self.db = None
         self.store = None
 
+    def log(self, message):
+        if self.server.context.settings.Ion.as_bool('verbose'):
+            cherrypy.log(message, "[%s]" % self.__class__.__name__)
+
     def connect(self):
-        ctx = self.server.context
-        db = Db(ctx)
+        db = Db(self.server)
         db.connect()
         self.db = db
         self.store = db.store
